@@ -1,3 +1,4 @@
+library("parallel")
 library("testthat")
 library("mapi")
 test_that("MAPI_RunOnGrid", {
@@ -5,7 +6,7 @@ test_that("MAPI_RunOnGrid", {
   data("metric")
   grid <- MAPI_GridHexagonal(samples, crs=3857, hw=250)
   set.seed(1234)  # for reproductibility
-  results <- MAPI_RunOnGrid(samples, metric, grid=grid, nbPermuts=50, nbCores=1)
+  results <- MAPI_RunOnGrid(samples, metric, grid=grid, nbPermuts=50, nbCores=1) # serial computation for reproductibility!
   expect_equal(sum(results$proba), 286.34)
   tails <- MAPI_Tails(results)
   expect_equal(nrow(tails[tails$tail=='upper',]), 1)
